@@ -340,6 +340,8 @@ class TestNestedTransitions(TestTransitions):
         states = ['standing', 'walking', {'name': 'caffeinated', 'children': ['dithering', 'running']}]
         transitions = [['walk', 'standing', 'walking'],
                        ['stop', 'walking', 'standing'],
+                       ['drink', 'caffeinated_dithering', '='],
+                       ['drink', 'caffeinated', 'caffeinated_dithering'],
                        ['drink', '*', 'caffeinated'],
                        ['walk', 'caffeinated', 'caffeinated_running'],
                        ['relax', 'caffeinated', 'standing']]
@@ -351,6 +353,10 @@ class TestNestedTransitions(TestTransitions):
         machine.drink()  # coffee time
         machine.state
         self.assertEqual(machine.state, 'caffeinated')
+        machine.drink()  # again!
+        self.assertEqual(machine.state, 'caffeinated_dithering')
+        machine.drink()  # and again!
+        self.assertEqual(machine.state, 'caffeinated_dithering')
         machine.walk()   # we have to go faster
         self.assertEqual(machine.state, 'caffeinated_running')
         machine.stop()   # can't stop moving!
@@ -398,6 +404,8 @@ class TestNestedTransitions(TestTransitions):
         self.assertTrue(m.is_B(allow_substates=True))
         m.do()
         self.assertEqual(m.state, 'B{0}1'.format(separator))
+        m = self.stuff.machine_cls(states=states, transitions=transitions, initial='B{0}2{0}b'.format(separator))
+        self.assertTrue('B{0}2{0}b'.format(separator), m.state)
 
     def test_get_triggers(self):
         seperator = self.state_cls.separator
@@ -450,7 +458,7 @@ class TestNestedTransitions(TestTransitions):
         exit_mock = MagicMock()
         enter_mock = MagicMock()
 
-        class Model():
+        class Model:
 
             def on_exit_A(self):
                 parent_mock()
@@ -472,6 +480,40 @@ class TestNestedTransitions(TestTransitions):
         self.assertTrue(enter_mock.called)
         self.assertFalse(parent_mock.called)
 
+    def test_trigger_parent_model_self(self):
+        parent_mock = MagicMock()
+        exit_mock = MagicMock()
+        enter_mock = MagicMock()
+
+        class CustomMachine(self.machine_cls):
+
+            def on_exit_A(self):
+                parent_mock()
+
+            def on_exit_A_1(self):
+                exit_mock()
+
+            def on_enter_A_2(self):
+                enter_mock()
+
+        machine = CustomMachine(states=[{'name': 'A', 'children': ['1', '2']}],
+                                transitions=[['go', 'A', 'A_2'], ['enter', 'A', 'A_1']], initial='A')
+        machine.enter()
+        self.assertFalse(parent_mock.called)
+        machine.go()
+        self.assertTrue(exit_mock.called)
+        self.assertTrue(enter_mock.called)
+        self.assertFalse(parent_mock.called)
+
+    def test_child_condition_persistence(self):
+        # even though the transition is invalid for the parent it is valid for the nested child state
+        # no invalid transition exception should be thrown
+        machine = self.machine_cls(states=[{'name': 'A', 'children': ['1', '2'], 'initial': '1',
+                                            'transitions': [{'trigger': 'go', 'source': '1', 'dest': '2',
+                                                             'conditions': self.stuff.this_fails}]}, 'B'],
+                                   transitions=[['go', 'B', 'A']], initial='A')
+        self.assertFalse(False, machine.go())
+
 
 class TestSeparatorsBase(TestCase):
 
